@@ -1,24 +1,26 @@
 #![doc = include_str!("../README.md")]
 
+mod attribute;
 pub mod buffer;
 pub mod draw_modes;
-pub mod gpu_init;
 pub mod program;
 pub mod renderer;
+pub mod shadow_gpu;
 pub mod state;
-pub mod types;
 pub mod uniform;
-pub mod vertex_attribute;
+pub mod webgl;
 
 pub use bytemuck;
-pub use limelight_derive::{vertex_attribute, VertexAttribute};
+pub use limelight_derive::{attribute, Attribute};
 
+pub use attribute::{Attribute, AttributeBinding};
+pub use buffer::{Buffer, DummyBuffer};
 pub use draw_modes::DrawMode;
-pub use buffer::{DummyBuffer, AttributeBuffer, BufferUsageHint};
-pub use program::{Program, GlProgram};
+pub use program::Program;
 pub use renderer::Renderer;
 pub use uniform::Uniform;
-pub use vertex_attribute::{VertexAttribute, VertexAttributeBinding};
+pub use webgl::types::AsSizedDataType;
+pub use webgl::buffer::{BufferBindPoint, BufferUsageHint};
 
 #[allow(unused)]
 macro_rules! console_log {
